/***** BEGIN LICENSE BLOCK *****
   - Version: MPL 1.1/GPL 2.0/LGPL 2.1
   -
   - The contents of this file are subject to the Mozilla Public License Version
   - 1.1 (the "License"); you may not use this file except in compliance with
   - the License. You may obtain a copy of the License at
   - http://www.mozilla.org/MPL/
   -
   - Software distributed under the License is distributed on an "AS IS" basis,
   - WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
   - for the specific language governing rights and limitations under the
   - License.
   -
   - The Original Code is "Plain Text To Link".
   -
   - The Initial Developer of the Original Code is Tommaso Beniero.
   - Portions created by the Initial Developer are Copyright (C) 2005 Tommaso Beniero.  
   - All Rights Reserved.
   -
   - Contributor(s): Tommaso Beniero <tommaso DOT beniero AT gmail DOT com>
   -
   - Alternatively, the contents of this file may be used under the terms of
   - either the GNU General Public License Version 2 or later (the "GPL"), or
   - the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
   - in which case the provisions of the GPL or the LGPL are applicable instead
   - of those above. If you wish to allow use of your version of this file only
   - under the terms of either the GPL or the LGPL, and not to allow others to
   - use your version of this file under the terms of the MPL, indicate your
   - decision by deleting the provisions above and replace them with the notice
   - and other provisions required by the LGPL or the GPL. If you do not delete
   - the provisions above, a recipient may use your version of this file under
   - the terms of any one of the MPL, the GPL or the LGPL.
   -
   - 
***** END LICENSE BLOCK *****/

/* Thanks to Ted Mielczarek for the functions unmangleURL and fixURL

/*
 * Copyright (c) 2001-2002  Ted Mielczarek
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

var myMenuItems = new Array("divisor", "pttl_menu", "pttl_menupopup", "open_here", "open_window", "open_tab", "add_bookmark", "divisor1", "new_email", "divisor2" , "search_google_groups_window", "search_google_groups_tab", "divisor3", "translate", "divisor4", "save", "append");  

// initialize function

function init() {
	
	var menu = document.getElementById("contentAreaContextMenu");
	menu.addEventListener("popupshowing",verSelText,false);

}

// it checks whether there's selected text or not. If it's true, the menu appears, otherwise it doesn't	

function verSelText() {

	var isTextSelection = false;
	if(gContextMenu) isTextSelection = gContextMenu.isTextSelected;
	for(var i=0; i<myMenuItems.length; i++) {
		var menuitem = document.getElementById(myMenuItems[i]);
		if(menuitem) {
			menuitem.hidden = !isTextSelection;
		}
	}
	
}

// it allows to obtain a string representing the selected text on the screen

function getString() {

	var focusedWindow = document.commandDispatcher.focusedWindow;
	var hlText = focusedWindow.getSelection.call(focusedWindow);
	hlText = hlText.toString();
	hlText = this.manipulateString(hlText);
	return hlText;

}

// it allows to eliminate all the unuseful charachters from the URL

function unmangleURL(url) {
	
	// eliminate all the white spaces in the URL
	while (url.indexOf(" ") != -1) {
		url = url.replace(" ",""); 		
	}
    // eliminate all the non-alphabetical characters at the beginning of the URL
	// example: [www.example.com --> www.example.com
	url = url.replace(/^[^a-zA-Z]+/, "");
	// eliminate unuseful characters the end of the URL
	// example: www.example.com] --> www.example.com
    url = url.replace(/[\.,\'\"\)\?!>\]]+$/, "");
    return url;
	
}

// it allows to correct the initial part of an URL  	

function fixURL(url) {

    if(url.search(/^\w+:\/\//) == -1) url = "http://" + url;
    if(url.search(/^h.+p:\/\//) != -1) url = url.replace(/^h.+p:\/\//, "http://");
    if(url.search(/^f.+p:\/\//) != -1) url = url.replace(/^f.+p:\/\//, "ftp://");
    return url;
  
}

// it allows to manipulate the email address

function manipulateEmail(addr) {

	if (addr.indexOf("@") == -1) {   
		addr = addr.replace(/^\s*(.*)/, "$1");
		addr = addr.replace(/\s*\ at\ \s*/gi, "@");
		addr = addr.replace(/\s*\ dot\ \s*/gi, ".");
	}
	while (addr.indexOf(" ") != -1) {
		addr = addr.replace(" ","");
	}
	return addr;
	
}

// it allows to remove white spaces before and after the selected text

function manipulateString(text) {

	l=text.length;
	while(text[0] == " ") {
		text.slice(1,l);
	}
	while(text[l] == " ") {
		text.slice(0,l-1);
	}
	return text;

}

// it allows to open the selected URL

function openUrl(n) {
	
	var URLAddress = this.getString();
	URLAddress = this.fixURL(this.unmangleURL(URLAddress));		
	switch(n) {
		// open the selected URL in the current window
		case 0:	{
			getBrowser().loadURI(URLAddress);
			break;
		}
		// open the selected URL in a new window
		case 1:	{
			window.open(URLAddress);
			break;
		}
		// open the selected URL in a new tab
		case 2:	{
			getBrowser().addTab(URLAddress);
			break;
		}
	}

}

// it allows to search the selected text in Google Groups

function searchGoogleGroups(n) {

	var searchText = this.getString();
	switch(n) {
		case 0:	{
			window.open("http://groups-beta.google.com/groups?q="+searchText);		
			break;
		}
		case 1:	{
			var browser=getBrowser();
			browser.addTab("http://groups-beta.google.com/groups?q="+searchText);
			break;
		}
	}

}
	
// it allows to add the selected link in Firefox Bookmarks

function addBookmark() {
	
	var docTitle = document.title; 
	var URLAddress = this.getString();
	var browser = getBrowser();
	URLAddress = this.fixURL(this.unmangleURL(URLAddress));		
	openDialog("chrome://browser/content/bookmarks/addBookmark.xul", "", "centerscreen,chrome,dialog=no,resizable=yes", URLAddress, URLAddress);

}

// it allows to send a email to the selected address

function newEmail() {
		
	var EmailAddr=this.getString();
	var browser=getBrowser();
	EmailAddr=this.manipulateEmail(EmailAddr);
	browser.loadURI("mailto:"+EmailAddr);

}

// it allows to translate selected text from English to the locale language

function translateFromEnglish() {

	var UA = navigator.userAgent;
	var text = this.getString();
	var browser=getBrowser();
	if(UA.search("en-US") != -1) {
		alert("This function is reserved only for non-English users");
	}
	else if(UA.search("it-IT") != -1) {
		browser.addTab("http://babelfish.altavista.com/babelfish/tr?doit=done&urltext="+text+"&lp=en_it");
	}
	else if(UA.search("de-DE") != -1) {
		browser.addTab("http://babelfish.altavista.com/babelfish/tr?doit=done&urltext="+text+"&lp=en_de");
	}
	else if(UA.search("es-ES") != -1) {
		browser.addTab("http://babelfish.altavista.com/babelfish/tr?doit=done&urltext="+text+"&lp=en_es");
	}
	else if(UA.search("fr-FR") != -1) {
		browser.addTab("http://babelfish.altavista.com/babelfish/tr?doit=done&urltext="+text+"&lp=en_fr");
	}
	else alert("Sorry, but this function is not present in your language yet.\nContact me at tommaso.beniero@gmail.com\nand if you want you can help me translating it in your language");

}

// it allows to save selected text to a file

function saveToAFile() {
	
	var strings = document.getElementById("pttlStrings"); 
    var UA = navigator.userAgent;
	var text = this.getString();
	var filePick = Components.classes["@mozilla.org/filepicker;1"].createInstance(Components.interfaces.nsIFilePicker);
	var stream = Components.classes["@mozilla.org/network/file-output-stream;1"].createInstance(Components.interfaces.nsIFileOutputStream);
	var winTitle = strings.getString("saveWinTitle");
	
    filePick.init(window, winTitle, filePick.modeSave);
	filePick.appendFilters(filePick.filterText);

	if (filePick.show() != filePick.returnCancel) {
		if (filePick.file.exists()) filePick.file.remove(true);
		filePick.file.create(filePick.file.NORMAL_FILE_TYPE, 0666);

		stream.init(filePick.file, 0x02, 0x200, null);
		
		stream.write("[PTTL]\n", 7);
		
		textLength = text.length;
		stream.write(text, textLength);

		stream.close();
	}
}

// it allows to append selected text to a previous PTTL file saved

function appendToAFile() {
	
	var strings = document.getElementById("pttlStrings");
    var UA = navigator.userAgent;
	var filePick = Components.classes["@mozilla.org/filepicker;1"].createInstance(Components.interfaces.nsIFilePicker);
	var stream = Components.classes["@mozilla.org/network/file-input-stream;1"].createInstance(Components.interfaces.nsIFileInputStream);
	var streamIO = Components.classes["@mozilla.org/scriptableinputstream;1"].createInstance(Components.interfaces.nsIScriptableInputStream);
	var streamWr = Components.classes["@mozilla.org/network/file-output-stream;1"].createInstance(Components.interfaces.nsIFileOutputStream);
	var overwriteCurrentList = false;
	var input;
	var inputArray;
	var validFile = false;
	var winTitle = strings.getString("appendWinTitle");
	var errMsg = strings.getString("appendErrMsg");
	var askOverwrite;
	var text = this.getString();
	
	filePick.init(window, winTitle, filePick.modeOpen);
	filePick.appendFilters(filePick.filterText);

	if (filePick.show() != filePick.returnCancel) {
		stream.init(filePick.file, 0x01, 0444, null);
		streamIO.init(stream);
		input = streamIO.read(stream.available());
		streamIO.close();
		stream.close();
		
		var matchStr = input.substr(0,6);
		if (matchStr=="[PTTL]") {
			var newText = text+"\n\n"+input;
			newTextLength = newText.length;
			
			streamWr.init(filePick.file, 0x02, 0x200, null);
			streamWr.write("[PTTL]\n", 7);
			streamWr.write(newText, newTextLength);
			streamWr.close();
		}
		else 
			alert(errMsg);
	}
	
}

window.addEventListener("load", init, false); 